@@ -50,14 +50,34 @@ class JobModel:
 
     @property
     def resources(self):
-        if 'resources' in self.config:
+        if 'resources' in self.config and isinstance(self.config['resources'], dict):
             return self.config['resources']
 
         return {}
 
+    def get_working_dir(self):
+        job_config = self.config
+
+        dir = '/'
+        if 'working_dir' in job_config and job_config['working_dir']:
+            dir = job_config['working_dir']
+        elif 'configPath' in job_config and job_config['configPath']:
+            dir = os.path.dirname(job_config['configPath'])
+
+        return dir.strip('/')
+
     def has_dpu(self):
         return 'dpu' in self.resources and self.resources['dpu'] > 0
 
+    def get_cpu(self):
+        return self.resources.get('cpu', 1)
+
+    def get_memory(self):
+        return self.resources.get('memory', 1)
+
+    def get_gpu(self):
+        return self.resources.get('gpu', 0)
+
     def get_batch_size(self):
         return self.job['config']['batchSize']
 
