@@ -127,12 +127,13 @@ class EventListener:
 def context():
     """
     Returns a new JobBackend instance which connects to AETROS Trainer
-    based on "model" in aetros.yml or env:AETROS_MODEL_NAME environment variable.
+    based on "model" in aetros.yml or (internal: env:AETROS_MODEL_NAME environment variable).
 
-    If env:AETROS_JOB_ID is not defined, it creates a new job.
+    internal: If env:AETROS_JOB_ID is not defined, it creates a new job.
 
     Job is ended either by calling JobBackend.done(), JobBackend.fail() or JobBackend.abort().
-    If the script ends without calling one of the methods above, JobBackend.done is automatically called.
+    If the script ends without calling one of the methods above, JobBackend.stop() is called and exit code defines
+    whether it is a fail() or done() result.
 
     :return: JobBackend
     """
@@ -150,8 +151,6 @@ def context():
         job.create()
         if not offline:
             job.connect()
-            if job.client.online:
-                job.git.push()
 
     job.start(offline=offline)
 
@@ -194,15 +193,18 @@ class JobLossChannel:
 
 
 class JobImage:
-    def __init__(self, id, image, label=None, pos=None):
-        self.id = id
-        if not isinstance(image, PIL.Image.Image):
+    def __init__(self, name, pil_image, label=None, pos=None):
+        self.id = name
+        if not isinstance(pil_image, PIL.Image.Image):
             raise Exception('JobImage requires a PIL.Image as image argument.')
 
-        self.image = image
+        self.image = pil_image
         self.label = label
         self.pos = pos
 
+        if self.pos is None:
+            self.pos = time.time()
+
 
 class JobChannel:
     NUMBER = 'number'
@@ -258,6 +260,7 @@ class JobChannel:
             'type': type or JobChannel.NUMBER,
             'main': main,
             'kpi': kpi,
+            'timed': True,
             'kpiTrace': kpiTrace,
             'maxOptimization': max_optimization,
             'xaxis': xaxis,
@@ -309,7 +312,7 @@ class JobBackend:
     :type job: dict
     """
 
-    def __init__(self, model_name=None, logger=None, config_path = 'aetros.yml', name=None):
+    def __init__(self, model_name=None, logger=None, config_path='aetros.yml', name=None):
         self.event_listener = EventListener()
 
         self.log_file_handle = None
@@ -643,22 +646,22 @@ class JobBackend:
     def on_parameter_changed(self, params):
         pass
 
-    def create_progress(self, id, total_steps=100):
-        if id in self.progresses:
-            return self.progresses[id]
+    def create_progress(self, name, total_steps=100):
+        if name in self.progresses:
+            return self.progresses[name]
 
         class Controller():
-            def __init__(self, git, id, total_steps=100):
+            def __init__(self, git, name, total_steps=100):
                 self.started = False
                 self.stopped = False
                 self.lock = Lock()
-                self.id = id
+                self.name = name
                 self.step = 0
                 self.steps = total_steps
                 self.eta = 0
                 self.last_call = 0
                 self.git = git
-                self._label = id
+                self._label = name
 
                 self.store()
 
@@ -671,7 +674,7 @@ class JobBackend:
                     'steps': self.steps,
                     'eta': self.eta,
                 }
-                self.git.store_file('aetros/job/progress/' + self.id + '.json', simplejson.dumps(info))
+                self.git.store_file('aetros/job/progress/' + self.name + '.json', simplejson.dumps(info))
 
             def label(self, label):
                 self._label = label
@@ -713,9 +716,9 @@ class JobBackend:
                 self.store()
                 self.lock.release()
 
-        self.progresses[id] = Controller(self.git, id, total_steps)
+        self.progresses[name] = Controller(self.git, name, total_steps)
 
-        return self.progresses[id]
+        return self.progresses[name]
 
     def epoch(self, epoch=None, total=None):
         self.progress(epoch, total)
@@ -1203,6 +1206,9 @@ class JobBackend:
             }
             config = find_config(self.config_path, logger=self.logger)
 
+            if not config['model']:
+                raise Exception('AETROS config file (aetros.yml) not found.')
+
             # first transform simple format in the full definition with parameter types
             # (string, number, group, choice_group, etc)
             full_hyperparameters = lose_parameters_to_full(config['parameters'])
@@ -1233,13 +1239,6 @@ class JobBackend:
 
         return self.job_id
 
-    def create_task(self, job_id, task_config, name, index):
-        # move to git
-        task_config['task'] = name
-        task_config['index'] = index
-
-        self.git.create_task_id(job_id, task_config)
-
     def is_simple_model(self):
         if not self.job:
             raise Exception('Job not loaded yet. Use load(id) first.')
@@ -1424,7 +1423,7 @@ class JobBackend:
 
     registered_actions = {}
 
-    def register_action(self,  callback, name=None, label=None, description=None):
+    def register_action(self, callback, name=None, label=None, description=None):
         if name is None:
             name = callback.__name__
 
@@ -1435,8 +1434,8 @@ class JobBackend:
 
             start_default_idx = len(inspect_args.args) - len(defaults)
 
-            for idx, name in enumerate(inspect_args.args):
-                args[name] = {'default': None, 'type': 'mixed'}
+            for idx, argname in enumerate(inspect_args.args):
+                args[argname] = {'default': None, 'type': 'mixed'}
 
                 if idx >= start_default_idx:
                     default_value = defaults[idx - start_default_idx]
@@ -1446,7 +1445,7 @@ class JobBackend:
                     if isinstance(default_value, float): arg_type = 'float'
                     if isinstance(default_value, bool): arg_type = 'bool'
 
-                    args[name] = {'default': default_value, 'type': arg_type}
+                    args[argname] = {'default': default_value, 'type': arg_type}
 
         value = {
             'label': label,
@@ -1471,9 +1470,6 @@ class JobBackend:
         action_name = params['name']
         action_value = params['value']
 
-        self.logger.debug("Trigger action: " + str(params))
-        self.logger.info("Trigger action %s(%s)" %( action_name, str(action_value)))
-
         if action_name in ['pause', 'continue']:
             try:
                 if action_name == 'pause': return self.on_pause()
@@ -1487,9 +1483,12 @@ class JobBackend:
                 self.logger.warning("Trigger action %s failed: %s" % (action_name, type(e).__name__ + ': ' + str(e)))
 
         if action_name not in self.registered_actions:
-            self.logger.warning('Received action ' + str(action_name) + ' but no callback registered.')
+            # Received action ' + str(action_name) + ' but no callback registered.')
             return
 
+        self.logger.debug("Trigger action: " + str(params))
+        self.logger.info("Trigger action %s(%s)" %( action_name, str(action_value)))
+
         config = self.registered_actions[action_name]
         callback = config['callback']
 
@@ -1733,13 +1732,13 @@ class JobBackend:
 
             self.git.commit_index('INSIGHT_EMBEDDING ' + str(x))
 
-    def add_insight_image_path(self, x, path, id=None, label=None):
+    def add_insight_image_path(self, x, path, name=None, label=None):
         image = PIL.Image.open(path)
 
-        if not id:
-            id = os.path.basename(path)
+        if not name:
+            name = os.path.basename(path)
 
-        return self.add_insight_image(x, JobImage(id, image, label))
+        return self.add_insight_image(x, JobImage(name, image, label))
 
     def add_insight_image(self, x, image):
         self.add_insight_images(x, [image])
@@ -1874,7 +1873,7 @@ class JobBackend:
             return True
 
         def failed(message):
-            self.logger.warning(
+            raise StdoutApiException(
                 "AETROS stdout API call %s failed: %s Following ignored: %s" % (action, message, str(data)))
 
         def default(attr, default=None):
