@@ -113,6 +113,7 @@ class BackendClient:
         self.connected = {}
 
         self.was_connected_once = {}
+        self.connected_since = {}
         self.read_unpacker = msgpack.Unpacker(encoding='utf-8')
 
     def on_sigint(self, sig, frame):
@@ -146,6 +147,7 @@ class BackendClient:
             self.ssh_channel[channel] = None
             self.connected[channel] = None
             self.registered[channel] = None
+            self.connected_since[channel] = 0
             self.was_connected_once[channel] = False
             self.stop_on_empty_queue[channel] = False
             self.channel_lock[channel] = Lock()
@@ -244,8 +246,10 @@ class BackendClient:
                 self.logger.debug('[%s] opened and received %d messages' % (channel, len(messages)))
                 self.connected[channel] = True
                 self.registered[channel] = self.on_connect(self.was_connected_once[channel], channel)
-                if self.registered[channel] and self.was_connected_once[channel]:
-                    self.logger.info("[%s] successfully reconnected." % (channel, ))
+                self.connected_since[channel] = time.time()
+
+                if channel == '' and self.registered[channel] and self.was_connected_once[channel]:
+                    self.logger.info("Successfully reconnected.")
 
             if not self.registered[channel]:
                 # make sure to close channel and connection first
@@ -342,7 +346,16 @@ class BackendClient:
             # python interpreter is already dying, so quit
             return
 
-        message = "[%s] Connection error" % (channel,)
+        if channel != '':
+            # we don't care about the file channel,
+            # it will reconnect anyway
+            return
+
+        since = 0
+        if self.connected_since[channel]:
+            since = time.time() - self.connected_since[channel]
+
+        message = "[%s] Connection error (connected for %d seconds) " % (channel, since)
 
         if error:
             import traceback
@@ -414,12 +427,12 @@ class BackendClient:
             if self.online is not False:
                 if self.is_connected(channel) and self.is_registered(channel):
                     try:
-                        # this blocks
+                        # this blocks if we have data
                         messages = self.read(channel)
 
                         if messages is not None:
                             self.logger.debug("[%s] Client: handle message: %s" % (channel, str(messages)))
-                            self.handle_messages(messages)
+                            self.handle_messages(channel, messages)
 
                         if self.stop_on_empty_queue[channel]:
                             return
@@ -621,6 +634,7 @@ class BackendClient:
             else:
                 self.queues[channel].append(message)
 
+            return message['_total']
         finally:
             self.queue_lock[channel].release()
 
@@ -675,7 +689,7 @@ class BackendClient:
             self.connection_error(channel, error)
             return False
 
-    def handle_messages(self, messages):
+    def handle_messages(self, channel, messages):
         self.lock.acquire()
         try:
             for message in messages:
@@ -808,15 +822,19 @@ class JobClient(BackendClient):
                 if channel == '':
                     self.event_listener.fire('registration')
 
-                self.handle_messages(messages)
+                self.handle_messages(channel, messages)
                 return True
 
         self.logger.error("[%s] Registration of job %s failed." % (channel, self.job_id,))
         return False
 
-    def handle_messages(self, messages):
+    def handle_messages(self, channel, messages):
+        BackendClient.handle_messages(self, channel, messages)
+
+        # only main channel should handle following messages
+        if channel != '':
+            return
 
-        BackendClient.handle_messages(self, messages)
         for message in messages:
             if self.external_stopped:
                 continue
@@ -824,6 +842,7 @@ class JobClient(BackendClient):
             if not isinstance(message, dict):
                 continue
 
+
             if 'a' in message and 'parameter-changed' == message['a']:
                 self.event_listener.fire('parameter_changed', {'values': message['values']})
 
