@@ -1,6 +1,9 @@
 from __future__ import absolute_import, print_function, division
 import argparse
 
+import sys
+
+
 class GPUCommand:
     def __init__(self, logger):
         self.logger = logger
@@ -12,9 +15,13 @@ class GPUCommand:
         import aetros.cuda_gpu
 
         parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter,
-                                         prog=aetros.const.__prog__ + ' run')
+                                         prog=aetros.const.__prog__ + ' gpu')
 
-        print("CUDA version: " +str(aetros.cuda_gpu.get_version()))
+        try:
+            print("CUDA version: " +str(aetros.cuda_gpu.get_version()))
+        except aetros.cuda_gpu.CudaNotImplementedException:
+            sys.stderr.write('It seems you dont have NVIDIA CUDA not installed properly.')
+            sys.exit(2)
 
         for gpu in aetros.cuda_gpu.get_ordered_devices():
             properties = aetros.cuda_gpu.get_device_properties(gpu['device'], all=True)
