@@ -3,7 +3,11 @@ from __future__ import print_function
 import argparse
 
 import six
+import sys
+
 from aetros import api
+from aetros.utils import read_home_config, KeyNotConfiguredException
+
 
 class IdCommand:
     def __init__(self, logger):
@@ -16,13 +20,19 @@ class IdCommand:
         import aetros.const
 
         parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter,
-                                         prog=aetros.const.__prog__ + ' run')
+                                         prog=aetros.const.__prog__ + ' id')
 
         parsed_args = parser.parse_args(args)
+        config = read_home_config()
 
-        user = api.user()
 
-        print("Key installed of account %s (%s)" % (user['username'], user['name']))
+        try:
+            user = api.user()
+        except KeyNotConfiguredException as e:
+            self.logger.error(str(e))
+            sys.exit(1)
+
+        print("Logged in as %s (%s) on %s" % (user['username'], user['name'], config['host']))
 
         if len(user['accounts']) > 0:
             for orga in six.itervalues(user['accounts']):
