@@ -3,11 +3,9 @@ import argparse
 import sys
 
 from aetros import api
-
-from aetros.utils import read_config, unpack_full_job_id, read_home_config
-
+from aetros.utils import read_home_config
 import aetros.const
-import os
+
 
 class StartCommand:
     def __init__(self, logger):
@@ -16,12 +14,13 @@ class StartCommand:
     def main(self, args):
         from aetros.starter import start
         parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter, prog=aetros.const.__prog__ + ' start')
-        parser.add_argument('name', nargs='?', help='the model name, e.g. aetros/mnist-network to start new job, or job id, e.g. user/modelname/0db75a64acb74c27bd72c22e359de7a4c44a20e5 to start a pre-created job.')
+        parser.add_argument('name', help='the model name, e.g. aetros/mnist-network to start new job, or job id, e.g. user/modelname/0db75a64acb74c27bd72c22e359de7a4c44a20e5 to start a pre-created job.')
 
         parser.add_argument('-i', '--image', help="Which Docker image to use for the command. Default read in aetros.yml. If not specified, command is executed on the host.")
         parser.add_argument('-l', '--local', action='store_true', help="Start the job immediately on the current machine.")
         parser.add_argument('-s', '--server', action='append', help="Limits the server pool to this server. Default not limitation or read in aetros.yml. Multiple --server allowed.")
         parser.add_argument('-b', '--branch', help="This overwrites the Git branch used when new job should be started.")
+        parser.add_argument('-c', '--config', help="Default /aetros.yml in Git root.")
         parser.add_argument('--priority', help="Increases or decreases priority. Default is 0.")
 
         parser.add_argument('--cpu', help="How many CPU cores should be assigned to job. Docker only.")
@@ -31,7 +30,7 @@ class StartCommand:
 
         parser.add_argument('--rebuild-image', action='store_true', help="Makes sure the Docker image is re-built without cache.")
 
-        parser.add_argument('--gpu-device', action='append', help="Which device id should be mapped into the NVIDIA docker container.")
+        parser.add_argument('--gpu-device', action='append', help="Which GPU device id should be mapped into the Docker container. Only with --local.")
 
         parser.add_argument('--max-time', help="Limit execution time in seconds. Sends SIGINT to the process group when reached.")
         parser.add_argument('--max-epochs', help="Limit execution epochs. Sends SIGINT to the process group when reached.")
@@ -43,21 +42,24 @@ class StartCommand:
 
         parsed_args = parser.parse_args(args)
 
-        home_config = read_home_config()
-        model_name = parsed_args.name
+        if not parsed_args.name:
+            print("fatal: no model defined. 'aetros start user/model-name'.")
+            sys.exit(2)
 
-        if model_name.count('/') > 1:
-            # start a concret job, by server command
+        if parsed_args.name and parsed_args.name.count('/') > 1:
+            # start a concrete job, used by server command
             gpu_devices = []
             if parsed_args.gpu_device:
                 gpu_devices = [int(x) for x in parsed_args.gpu_device]
 
-            start(self.logger, model_name, cpus=int(parsed_args.cpu), memory=int(parsed_args.memory),
+            start(self.logger, parsed_args.name, cpus=int(parsed_args.cpu), memory=int(parsed_args.memory),
                 gpu_devices=gpu_devices)
             return
 
-        # create a new job
+        home_config = read_home_config()
+        model_name = parsed_args.name
 
+        # create a new job
         hyperparameter = {}
         if parsed_args.param:
             for param in parsed_args.param:
@@ -88,24 +90,30 @@ class StartCommand:
         if parsed_args.rebuild_image:
             job_config['config']['rebuild_image'] = True
 
-        if 'resources' not in job_config:
-            job_config['resources'] = {}
-
         if parsed_args.server:
             job_config['servers'] = []
             for name in parsed_args.server:
                 job_config['servers'].append(name)
 
-        job_config['resources'] = job_config.get('resources', {})
-        resources = job_config['resources']
-        resources['cpu'] = int(parsed_args.cpu or resources.get('cpu', 1))
-        resources['memory'] = int(parsed_args.memory or resources.get('memory', 1))
-        resources['gpu'] = int(parsed_args.gpu or resources.get('gpu', 0))
-        resources['gpu_memory'] = int(parsed_args.gpu_memory or resources.get('gpu_memory', 0))
+        job_config['resources'] = {}
+
+        if parsed_args.cpu:
+            job_config['resources']['cpu'] = int(parsed_args.cpu)
+
+        if parsed_args.memory:
+            job_config['resources']['memory'] = int(parsed_args.memory)
+
+        if parsed_args.gpu:
+            job_config['resources']['gpu'] = int(parsed_args.gpu)
+
+        if parsed_args.gpu_memory:
+            job_config['resources']['gpu_memory'] = int(parsed_args.gpu_memory)
+
+        config_path = parsed_args.config or 'aetros.yml'
 
         try:
             self.logger.debug("Create job ...")
-            created = api.create_job(model_name, parsed_args.local, hyperparameter, parsed_args.dataset, config=job_config)
+            created = api.create_job(model_name, config_path, parsed_args.local, hyperparameter, parsed_args.dataset, config=job_config)
         except api.ApiError as e:
             if 'Connection refused' in e.error:
                 self.logger.error("You are offline")
@@ -115,15 +123,6 @@ class StartCommand:
         self.logger.info("Job %s/%s created." % (model_name, created['id']))
 
         if parsed_args.local:
-            cpus = job_config['resources']['cpu']
-            memory = job_config['resources']['memory']
-
-            if not parsed_args.gpu_device and job_config['resources']['gpu'] > 0:
-                # if requested 2 GPUs and we have 3 GPUs with id [0,1,2], gpus should be [0,1]
-                parsed_args.gpu_device = []
-                for i in range(0, job_config['resources']['gpu']):
-                    parsed_args.gpu_device.append(i)
-
-            start(self.logger, model_name + '/' + created['id'], cpus=cpus, memory=memory, gpu_devices=parsed_args.gpu_device)
+            start(self.logger, model_name + '/' + created['id'], gpu_devices=parsed_args.gpu_device)
         else:
             print("Open http://%s/model/%s/job/%s to monitor it." % (home_config['host'], model_name, created['id']))
