@@ -1,6 +1,8 @@
 from __future__ import absolute_import
 
 import sys
+import traceback
+
 import six
 from threading import Timer, Thread, Lock
 
@@ -12,9 +14,10 @@ def drain_stream(stream, decode='utf-8'):
         try:
             # read() needs to block
             # buf = os.read(buffer.fileno(), 4096)
-            buf = stream.read(1)
+            buf = stream.read(1024)
             if buf == six.b(''):
                 break
+
             content += buf
         except Exception:
             break
@@ -61,15 +64,17 @@ class GeneralLogger(object):
                 if self.job_backend.write_log(self.buffer):
                     self.buffer = ''
 
-    def attach(self, buffer, read_line=False):
+    def attach(self, buffer, read_line=None):
         """
         Read buffer until end (read() returns '') and sends it to self.logger and self.job_backend.
 
-        :param buffer: a buffer instance with block read() method
+        :param buffer: a buffer instance with block read() or readline() method
+        :param read_line: callable or True to read line per line. If callable is given, it will be executed per line
+                          and ignores does not redirect the line to stdout/logger when callable returns False.
         """
 
         bid = id(buffer)
-        self.attach_last_messages[bid] = six.b('')
+        self.attach_last_messages[bid] = b''
 
         lock = Lock()
 
@@ -78,30 +83,34 @@ class GeneralLogger(object):
             while True:
 
                 try:
-                    # read() needs to block
+                    # readline() needs to block
                     # buf = os.read(buffer.fileno(), 4096)
-                    if read_line:
-                        buf = buffer.readline()
-                    else:
-                        buf = buffer.read(1)
-                    if buf == six.b(''):
+                    buf = buffer.readline()
+                    if buf == b'':
                         break
 
+                    if read_line and callable(read_line):
+                        res = read_line(buf)
+                        if res is False:
+                            continue
+                        elif res is not None:
+                            buf = res
+                            if hasattr(buf, 'encode'):
+                                buf = buf.encode("utf-8", 'replace')
+
                     self.attach_last_messages[bid] += buf
 
                     if len(self.attach_last_messages[bid]) > 21 * 1024:
                         self.attach_last_messages[bid] = self.attach_last_messages[bid][-20 * 1024:]
 
                     self.write(buf)
-                except ValueError as e:
-                    if 'operation on closed' in e.message:
-                        break
-
-                except Exception as e:
+                except (KeyboardInterrupt, SystemExit):
+                    raise
+                except Exception:
                     # we need to make sure, we continue to read otherwise the process of this buffer
                     # will block and we have a stuck process.
-                    sys.__stderr__.write(str(type(e))+': ' + str(e))
-                    pass
+                    sys.__stderr__.write(traceback.format_exc() + '\n')
+                    sys.__stderr__.flush()
 
             lock.release()
 
@@ -120,10 +129,13 @@ class GeneralLogger(object):
         try:
             self.lock.acquire()
 
+            if b'' == message:
+                return
+
             if hasattr(message, 'decode'):
                 # don't decode string again
                 # necessary for Python3
-                message = message.decode('utf-8')
+                message = message.decode("utf-8", 'replace')
 
             self.logger.write(message)
             self.logger.flush()
@@ -142,7 +154,12 @@ class GeneralLogger(object):
                 if not self.last_timer:
                     self.last_timer = Timer(1.0, self.send_buffer)
                     self.last_timer.start()
-        except Exception as e:
-            sys.__stderr__.write(str(e))
+
+        except (KeyboardInterrupt, SystemExit):
+            raise
+        except Exception:
+            sys.__stderr__.write(traceback.format_exc() + '\n')
+            sys.__stderr__.flush()
         finally:
-            self.lock.release()
+            if self.lock.locked():
+                self.lock.release()
