@@ -24,7 +24,7 @@ class GitCommandException(Exception):
     cmd = None
 
 
-def start(logger, full_id, fetch=True, env=None, volumes=None, cpus=1, memory=1, gpu_devices=None, offline=False):
+def start(logger, full_id, fetch=True, env=None, volumes=None, cpus=None, memory=None, gpu_devices=None, offline=False):
     """
     Starts the job with all logging of a job_id
     """
@@ -44,6 +44,20 @@ def start(logger, full_id, fetch=True, env=None, volumes=None, cpus=1, memory=1,
     job_backend.start(collect_system=False, offline=offline)
     job_backend.set_status('PREPARE', add_section=False)
 
+    job = job_backend.get_job_model()
+
+    if not cpus:
+        cpus = job.get_cpu()
+
+    if not memory:
+        memory = job.get_memory()
+
+    if not gpu_devices and job.get_gpu():
+        # if requested 2 GPUs and we have 3 GPUs with id [0,1,2], gpus should be [0,1]
+        gpu_devices = []
+        for i in range(0, job.get_gpu()):
+            gpu_devices.append(i)
+
     start_command(logger, job_backend, env, volumes, cpus=cpus, memory=memory, gpu_devices=gpu_devices, offline=offline)
 
 
@@ -77,6 +91,7 @@ def start_command(logger, job_backend, env_overwrite=None, volumes=None, cpus=1,
         env['AETROS_SSH_KEY_BASE64'] = open(get_ssh_key_for_host(home_config['host']), 'r').read()
 
     job_config = job_backend.job['config']
+    job = job_backend.get_job_model()
 
     if 'command' not in job_config:
         job_backend.fail('No "command" given. See Configuration section in the documentation.')
@@ -260,8 +275,8 @@ def start_command(logger, job_backend, env_overwrite=None, volumes=None, cpus=1,
                 # new shells unset LD_LIBRARY_PATH automatically, so we make sure it will be there again
                 f.write('export LD_LIBRARY_PATH=$LD_LIBRARY_PATH_ORI;\n')
 
-            if 'working_dir' in job_config and job_config['working_dir']:
-                f.write('cd %s;\n' % (job_config['working_dir'],))
+            if job.get_working_dir():
+                f.write('cd %s;\n' % (job.get_working_dir(),))
 
             f.write(job_command)
             f.close()
@@ -281,7 +296,7 @@ def start_command(logger, job_backend, env_overwrite=None, volumes=None, cpus=1,
 
         def exec_command(id, command, job_command):
             write_command_sh(job_command)
-            print('$ ' + job_command.strip() + '\n')
+            print('%s $ %s' % ('/' + job.get_working_dir(), job_command.strip()))
             args = command
             logger.debug('$ ' + ' '.join([simplejson.dumps(a) for a in args]))
             state['last_process'] = subprocess.Popen(
@@ -448,7 +463,8 @@ def docker_image_information(logger, home_config, job_backend):
             job_backend.set_system_info('image/architecture', inspection['Architecture'])
             job_backend.set_system_info('image/os', inspection['Os'])
             job_backend.set_system_info('image/size', inspection['Size'])
-            job_backend.set_system_info('image/rootfs', inspection['RootFS'])
+            if 'RootFS' in inspection:
+                job_backend.set_system_info('image/rootfs', inspection['RootFS'])
 
 
 def docker_pause(logger, home_config, job_backend):
