@@ -703,7 +703,6 @@ def find_config(path = None, error_on_missing=False, return_default=True, logger
 
         if config['model']:
             if 'init_config_path' in config:
-                config['working_dir'] = os.path.relpath(os.path.dirname(config['init_config_path']), config['root'])
                 config['configPath'] = os.path.relpath(config['init_config_path'], config['root'])
                 del config['init_config_path']
 
@@ -730,6 +729,11 @@ def find_config_path(dir = None):
         else:
             new_path = os.path.realpath(dir + '/..')
             if new_path == dir:
+                # means we are at the end
+                return None
+
+            if new_path == os.path.realpath(os.path.expanduser('~')):
+                # means we are at the home folder, where the home configuration is
                 return None
 
             dir = new_path
